/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.util.List;

/**
 * @author Michael Hashimoto
 */
public class PortalAcceptancePullRequestJob extends PortalRepositoryJob {

	public PortalAcceptancePullRequestJob(String url) {
		this(url, "default");
	}

	public PortalAcceptancePullRequestJob(String url, String testSuiteName) {
		super(url);

		_testSuiteName = testSuiteName;
	}

	@Override
	public List<String> getBatchNames() {
		String testBatchNames = portalTestProperies.getProperty(
			"test.batch.names[" + _testSuiteName + "]");

		if (testBatchNames == null) {
			testBatchNames = portalTestProperies.getProperty(
				"test.batch.names");
		}

		return getListFromString(testBatchNames);
	}

	@Override
	public List<String> getDistTypes() {
		String testBatchDistAppServers = portalTestProperies.getProperty(
			"test.batch.dist.app.servers[" + _testSuiteName + "]");

		if (testBatchDistAppServers == null) {
			testBatchDistAppServers = portalTestProperies.getProperty(
				"test.batch.dist.app.servers");
		}

		return getListFromString(testBatchDistAppServers);
	}

	public String getTestSuiteName() {
		return _testSuiteName;
	}

	private final String _testSuiteName;

}