/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.IOException;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Properties;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.lang.StringUtils;

/**
 * @author Michael Hashimoto
 */
public abstract class PortalRepositoryJob extends RepositoryJob {

	@Override
	public List<String> getBatchNames() {
		String testBatchNames = portalTestProperies.getProperty(
			"test.batch.names");

		return getListFromString(testBatchNames);
	}

	@Override
	public List<String> getDistTypes() {
		String testBatchDistAppServers = portalTestProperies.getProperty(
			"test.batch.dist.app.servers");

		return getListFromString(testBatchDistAppServers);
	}

	protected PortalRepositoryJob(String jobName) {
		super(jobName);

		branchName = _getBranchName();
		gitWorkingDirectory = _getGitWorkingDirectory();

		portalTestProperies = getGitWorkingDirectoryProperties(
			"test.properties");
	}

	protected List<String> getListFromString(String string) {
		if (string == null) {
			return Collections.emptyList();
		}

		List<String> list = new ArrayList<>();

		for (String item : StringUtils.split(string, ",")) {
			if (list.contains(item) || item.startsWith("#")) {
				continue;
			}

			list.add(item);
		}

		Collections.sort(list);

		return list;
	}

	protected final Properties portalTestProperies;

	private String _getBranchName() {
		Matcher matcher = _pattern.matcher(jobName);

		if (matcher.find()) {
			return matcher.group("branchName");
		}

		return "master";
	}

	private GitWorkingDirectory _getGitWorkingDirectory() {
		String branchName = _getBranchName();
		String workingDirectoryPath = "/opt/dev/projects/github/liferay-portal";

		if (!branchName.equals("master")) {
			workingDirectoryPath = JenkinsResultsParserUtil.combine(
				workingDirectoryPath, "-", branchName);
		}

		try {
			return new GitWorkingDirectory(branchName, workingDirectoryPath);
		}
		catch (IOException ioe) {
			throw new RuntimeException(
				"Invalid Git working directory " + workingDirectoryPath, ioe);
		}
	}

	private static final Pattern _pattern = Pattern.compile(
		"[^\\(]+\\((?<branchName>[^\\)]+)\\)");

}